<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>AutoUpdater</name>
    <message>
        <source>No ssl configuration!
OpenSSL might not be installed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save the Birdtray installer:
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to download the Birdtray installer:
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Installer download failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to start the Birdtray installer.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BirdtrayApp</name>
    <message>
        <source>A free system tray notification for new mail for Thunderbird.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display the contents of the given mork database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>databaseFile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decode an IMAP Utf7 string.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>string</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show the settings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset the settings to the defaults.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle the Thunderbird window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show the Thunderbird window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide the Thunderbird window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Write log to a file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sorry, the system tray cannot be controlled by this add-on on your operating system.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DialogAddEditNewEmail</name>
    <message>
        <source>&quot;New Email&quot; Entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(Optional) Prefilled fields</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Email subject:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Email message text:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Email recipient:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No name specified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name cannot be empty.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DialogLogOutput</name>
    <message>
        <source>Debug log viewer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DialogSettings</name>
    <message>
        <source>Birdtray Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Mail Notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show unread count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Different icon when unread:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fastest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Icon (Ctrl-click to reset):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This notification color will be used when more than one monitored account has unread emails.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Multiple notification color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This changes the font thickness, i.e. makes the font bold.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blinking speed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font style:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bold:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notification border color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monitoring</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Accounts to monitor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow ignoring the current unread email counter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hiding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Launching and Hiding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Thunderbird when Birdtray starts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;When both Thunderbird and Birdtray are set to start with the operating system, this usually results in two copies of Thunderbird being launched. Here you can add a delay before Thunderbird is launched, to prevent this.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> second delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>with a </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>and hide it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Terminate Thunderbird when quitting Birdtray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide/show Thunderbird window when clicking on tray icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Thunderbird window when it is minimized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show red X in tray icon if Thunderbird is not running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restart Thunderbird if it was closed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Email</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable New Email submenu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please do not change these settings unless you understand what you&apos;re doing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thunderbird window name pattern:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Minimum notification font size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> points</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When blinking, use the fade-in/fade-out transition (increases CPU use!)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make the system tray icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check for new updates when Birdtray starts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check for new updates on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check for a new Birdtray version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Version check failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to check for a new Birdtray version:
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Checking...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose the new icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Images (*.png *.svg *.svgz)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not load the icon from this file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thunderbird command line:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This is the full command-line (with arguments) which will be used to start Thunderbird. Arguments are space-separated, but spaces in quotes are allowed, i.e. something like &lt;span style=&quot; font-weight:600;&quot;&gt;&amp;quot;C:\Program Files\tb.exe&amp;quot; --profile test&lt;/span&gt; will work.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore all unread email that are present when Birdtray starts. Only new emails will be taken into account by the unread counter.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>opaque when new mail is present,</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hide it if no new mail is present.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose one or more MSF files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mail Index (*.msf)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No new updates found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show log window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Force index file re-read every</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translations are powered by the community:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translators</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Active maintainers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contributors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If this box is checked, the Birdtray icon will show the number of unread emails.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;If it is unchecked, no count will be shown, and you will only know about unread emails because of the blinking or different icon, depending on your settings.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unread change cmd:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select mail folders for watching.&lt;br/&gt;&lt;br/&gt;If the dialog doesn&apos;t show your folder, &lt;i&gt;Ctrl + Shift click&lt;/i&gt; to open a file selection dialog that allows adding any mork file.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not load the icon from this file. Try loading the icon in an image editing tool and saving it in a different format.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If not empty, this command will be invoked every time the unread counter changes (including when it becomes zero). It is invoked via shell, as-is, with %NEW% replaced by the new unread count value and %OLD% replaced with the old unread count value (which may be the same as new).&lt;/p&gt;&lt;p&gt;Most users don&apos;t need this functionality and should leave it empty.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Support non-NETWM compliant WMs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If your desktop manager is not fully NETWM compliant, you may need to check this checkbox so it can detect Thunderbird window and is able to minimise and hide it.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>At startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When hiding Thunderbird</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When showing Thunderbird</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If enabled, this option adds the &amp;quot;Ignore currently unread emails&amp;quot; action to the context menu. This action allows you to ignore the emails which are currently unread. Birdtray would then pretend there are no unread emails left, and would only show new emails over the ignored count.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;For example, if there were 10 unread emails, and you clicked on &amp;quot;Ignore&amp;quot; action, Birdtray will show no unread email indicator as long as unread email count remains at 10. Once new email is received and you have 11 total unread emails, Birdtray will show the new email count as 1.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Thunderbird by clicking on the tray icon if it was closed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When detecting a change, wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> milliseconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>before updating the unread counter.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thunderbird process name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-weight:600;&quot;&gt;Birdtray version [VERSION] compiled at [DATE] using Qt [QT_VERSION].&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Copyright (C) 2018 by George Yunaev, &lt;/span&gt;&lt;a href=&quot;mailto:gyunaev@ulduzsoft.com&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;gyunaev@ulduzsoft.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Birdtray is FREE SOFTWARE, which is licensed under General Public License v3. To clarify further, you can use it for any purpose, including commercial, without paying anything. &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;To ask for help, request a feature or report a bug use the &lt;/span&gt;&lt;a href=&quot;https://github.com/gyunaev/birdtray&quot;&gt;&lt;span style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;Github project page&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;For those of you who appreciate my work on Birdtray, which is being developed in my free time, you can do it here: &lt;/span&gt;&lt;a href=&quot;https://paypal.me/ulduzsoft&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;https://paypal.me/ulduzsoft&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Thank you for your continuous support!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Log</name>
    <message>
        <source>Fatal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fatal error: %1

Log file is written into file %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to open log file %1: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MailAccountDialog</name>
    <message>
        <source>Choose the Thunderbird profiles path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No folder selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No mail folder was selected to monitor.
Do you want to continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Accounts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select the directory that contains the Thunderbird profiles.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thunderbird Profiles Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select the mail accounts you want to monitor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Email Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notification Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you monitor multiple folders, the default notification color is used to show the sum of all unread mails.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 (Profile)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No mail profiles were found.
Please make sure you selected the correct profiles directory.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ModelAccountTree</name>
    <message>
        <source>Account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notification color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ModelNewEmails</name>
    <message>
        <source>Menu entry item</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MorkParser</name>
    <message>
        <source>Couldn&apos;t open file: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid format.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parsing error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unexpected EOF.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid comment.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Format error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unexpected end of group.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Could not save the settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not save the settings into file %1:
%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sqlite based accounts migrated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You had configured monitoring of one or more mail folders using the Sqlite parser. This method has been removed. Your configurations has been migrated to the Mork parser, but some configured mail folders could not be found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You had configured monitoring of one or more mail accounts using the Sqlite parser. This method has been removed. Your configurations has been migrated to the Mork parser. Please verify that all accounts were mapped correctly.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot load default system tray icon.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Would you like to set up Birdtray?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have not yet configured any email folders to monitor. Would you like to do it now?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Thunderbird</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Thunderbird</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Email</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Email Message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5 minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>10 minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>30 minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 hour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4 hours</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snooze for ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsnooze</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore unread emails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot start Thunderbird</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error starting Thunderbird, because we could not attach to the updater:

%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore unread emails (now %1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error starting Thunderbird as &apos;%1 %2&apos;:

%3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t ask again</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UnreadMonitor</name>
    <message>
        <source>Unable to watch %1 for changes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read from %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Birdtray Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A new version of Birdtray is available.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignore this version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ca. %1 Mb</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update and restart</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateDownloadDialog</name>
    <message>
        <source>Birdtray Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading Birdtray update...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading Birdtray installer...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download finished. Restart and update Birdtray?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading Birdtray installer... (%1 Mb / %2 Mb).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
